==> DAPAR_1.8.7.tar.gz: DAPAR/inst/doc/Prostar_UserManual.R <==
### R code from vignette source 'Prostar_UserManual.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: style-Sweave
###################################################
BiocStyle::latex()


###################################################
### code chunk number 2: installProstaRBiocond (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("Prostar")


###################################################
### code chunk number 3: runProstarStandalone (eval = FALSE)
###################################################
## library(Prostar)
## Prostar()


###################################################
### code chunk number 4: getProstarInstallDir (eval = FALSE)
###################################################
## installed.packages()["Prostar","LibPath"]


###################################################
### code chunk number 5: installDAPARBiocond (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("DAPAR")


###################################################
### code chunk number 6: installDAPARdata (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("DAPARdata")


###################################################
### code chunk number 7: getDAPARdataInstallDir (eval = FALSE)
###################################################
## installed.packages()["DAPARdata","LibPath"]


###################################################
### code chunk number 8: sessionLog (eval = FALSE)
###################################################
## getProcessingInfo(obj)


###################################################
### code chunk number 9: diffAnalysis (eval = FALSE)
###################################################
## res <- diffAnaLimma(imputed_dataset, condition1, condition2)
## obj <- diffAnaSave(imputed_dataset, res, "limma", condition1, condition2)


###################################################
### code chunk number 10: sessioninfo
###################################################
toLatex(sessionInfo())

==> DAPAR_1.12.11.tar.gz: DAPAR/inst/doc/Prostar_UserManual.R <==
### R code from vignette source 'Prostar_UserManual.Rnw'
### Encoding: UTF-8

###################################################
### code chunk number 1: style-Sweave
###################################################
BiocStyle::latex()


###################################################
### code chunk number 2: installProstaRBiocond (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("Prostar")


###################################################
### code chunk number 3: runProstarStandalone (eval = FALSE)
###################################################
## library(Prostar)
## Prostar()


###################################################
### code chunk number 4: getProstarInstallDir (eval = FALSE)
###################################################
## installed.packages()["Prostar","LibPath"]


###################################################
### code chunk number 5: installDAPARBiocond (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("DAPAR")


###################################################
### code chunk number 6: installDAPARdata (eval = FALSE)
###################################################
## source("http://www.bioconductor.org/biocLite.R")
## biocLite("DAPARdata")


###################################################
### code chunk number 7: getDAPARdataInstallDir (eval = FALSE)
###################################################
## installed.packages()["DAPARdata","LibPath"]


###################################################
### code chunk number 8: sessionLog (eval = FALSE)
###################################################
## getProcessingInfo(obj)


###################################################
### code chunk number 9: diffAnalysis (eval = FALSE)
###################################################
## res <- diffAnaLimma(imputed_dataset, condition1, condition2)
## obj <- diffAnaSave(imputed_dataset, res, "limma", condition1, condition2)


###################################################
### code chunk number 10: GOClassif (eval = FALSE)
###################################################
## ggo <- group_GO(data, idFrom="UNIPROT", orgdb=org.Hs.eg.db, ont="MF", level=2)
## barplotGroupGO_HC(ggo)


###################################################
### code chunk number 11: GOEnrichment (eval = FALSE)
###################################################
## univ.Hs<-univ_AnnotDbPkg(org.Hs.eg.db)
## ego<-group_GO(data, idFrom="UNIPROT", orgdb=org.Hs.eg.db, ont="MF", 
##               universe=univ.Hs, pval=0.05, pAdjustMethod="BH")
## barplotEnrichGO_HC(ego)
## scatterplotEnrichGO_HC(ego)


###################################################
### code chunk number 12: sessioninfo
###################################################
toLatex(sessionInfo())
